Abstract Syntax Tree — yaflux documentation

Skip to main content
`Ctrl`+`K`

# Abstract Syntax Tree

exception yaflux._ast.AstSelfMutationError(func_name, mutated)

  Bases: `Exception`

  Raised when self is mutated in a function.

exception yaflux._ast.AstUndeclaredUsageError(func_name, undeclared)

  Bases: `Exception`

  Raised when an undeclared variable is used in the AST.

yaflux._ast.validate_ast(func, requires, mutates)

  Parse a function’s AST and perform validation checks.

  Return type:

    `None`